import{a as s,b as c,o as n,g as u}from"./index-Bg_jr9nS.js";const i={__name:"index",setup(p){const e=s(),t=c(),{params:o,query:a}=e,{path:r}=o;return t.replace({path:"/"+r,query:a}),(_,m)=>(n(),u("div"))}};export{i as default};
